<?php
define('XMLRPC_REQUEST', true);

/** Include the bootstrap for setting up WordPress environment */
require_once('wp-load.php');

require_once(ABSPATH . 'wp-admin/includes/admin.php');
require_once(ABSPATH . WPINC . '/class-IXR.php');

class XMLRPCServerExtended extends IXR_Server {

	public function XMLRPCServerExtended() {
		$this->IXR_Server(array(
	        'wp_extended.create_product' => 'this:create_product',
	    ));
	}

	/**
	 * Создание страницы типа 'Product'.
	 * 
	 * @param array $args массив с данными
	 * $args[0] - имя пользователя
	 * $args[1] - пароль
	 * $args[2] - массив с данными для создания поста 
	 * (перечень полей здесь - http://codex.wordpress.org/Function_Reference/wp_insert_post)
	 * @return - сообщение о результате создания страницы
	 */
	
	public function create_product($args) {
		$username = $args[0];
		$userpass = $args[1];
		$post_data = $args[2];
		//проверяем логин/пароль
		if ( $this->login_pass_ok( $username, $userpass ) ) {
			//получаем id пользователя
			$user_data = get_userdatabylogin( $username );
			$post_data['post_type'] = 'example_product';
			$post_data['post_author'] = $user_data->ID;
			$post_data['ping_status'] = get_option( 'default_ping_status' );
			//Добавляем пост
			if ( 0 !== ( $post_id = wp_insert_post( $post_data ) ) ) {
				return 'Created post '.$post_id;
			}
			return 'Post add error';
		}
	}
	
	/**
	 * Check user's credentials.
	 *
	 * @since 1.5.0
	 *
	 * @param string $user_login User's username.
	 * @param string $user_pass User's password.
	 * @return bool Whether authentication passed.
	 * @deprecated use wp_xmlrpc_server::login
	 * @see wp_xmlrpc_server::login
	 */
	function login_pass_ok($user_login, $user_pass) {
		if ( !get_option( 'enable_xmlrpc' ) ) {
			$this->error = new IXR_Error( 405, sprintf( __( 'XML-RPC services are disabled on this site.  An admin user can enable them at %s'),  admin_url('options-writing.php') ) );
			return false;
		}

		if (!user_pass_ok($user_login, $user_pass)) {
			$this->error = new IXR_Error(403, __('Bad login/pass combination.'));
			return false;
		}
		return true;
	}

}

$server = new XMLRPCServerExtended();